summaryrefslogtreecommitdiff
path: root/include/glibtop/procsegment.h
diff options
context:
space:
mode:
authorMartin Baulig <martin@home-of-linux.org>1999-03-31 16:53:05 +0000
committerMartin Baulig <martin@src.gnome.org>1999-03-31 16:53:05 +0000
commitede4594dd9a4e16b35723c9d2fc51c4fdfa74e97 (patch)
tree33792087ca950c1e51e5ad3d2ce1c9d090e8c5ac /include/glibtop/procsegment.h
parent3a7f02352a458c592ae23ed93228636535af1831 (diff)
downloadlibgtop-ede4594dd9a4e16b35723c9d2fc51c4fdfa74e97.tar.gz
Added some new features.
1999-03-30 Martin Baulig <martin@home-of-linux.org> Added some new features. * (glibtop_uptime): Added `boot_time', boot time in seconds since the epoch. * (glibtop_proc_state): Changed `state' from char to unsigned. `uid' and `gid' are effective uid and gid; added comment. Added `ruid' and `rgid' for guaranteed-to-be-correct real uid/gid. For SMP systems: added `has_cpu', `processor' and `last_processor'. * (glibtop_proc_uid): Added suid, sgid, fsuid, fsgid, ngroups, groups. * (glibtop_proc_segment): Added start_data, end_data, start_brk, end_brk, start_mmap, arg_start, arg_end, env_start, env_end. * include/glibtop/procstate.h: Define some constants for the `state' field of glibtop_proc_state. * include/glibtop/prockernel.h: Define some constands for the `k_flags' field of glibtop_proc_kernel.
Diffstat (limited to 'include/glibtop/procsegment.h')
-rw-r--r--include/glibtop/procsegment.h29
1 files changed, 23 insertions, 6 deletions
diff --git a/include/glibtop/procsegment.h b/include/glibtop/procsegment.h
index d0758c59..1c243528 100644
--- a/include/glibtop/procsegment.h
+++ b/include/glibtop/procsegment.h
@@ -38,9 +38,18 @@ BEGIN_LIBGTOP_DECLS
#define GLIBTOP_PROC_SEGMENT_DIRTY_SIZE 4
#define GLIBTOP_PROC_SEGMENT_START_CODE 5
#define GLIBTOP_PROC_SEGMENT_END_CODE 6
-#define GLIBTOP_PROC_SEGMENT_START_STACK 7
-
-#define GLIBTOP_MAX_PROC_SEGMENT 8
+#define GLIBTOP_PROC_SEGMENT_START_DATA 7
+#define GLIBTOP_PROC_SEGMENT_END_DATA 8
+#define GLIBTOP_PROC_SEGMENT_START_BRK 9
+#define GLIBTOP_PROC_SEGMENT_END_BRK 10
+#define GLIBTOP_PROC_SEGMENT_START_STACK 11
+#define GLIBTOP_PROC_SEGMENT_START_MMAP 12
+#define GLIBTOP_PROC_SEGMENT_ARG_START 13
+#define GLIBTOP_PROC_SEGMENT_ARG_END 14
+#define GLIBTOP_PROC_SEGMENT_ENV_START 15
+#define GLIBTOP_PROC_SEGMENT_ENV_END 16
+
+#define GLIBTOP_MAX_PROC_SEGMENT 17
typedef struct _glibtop_proc_segment glibtop_proc_segment;
@@ -54,10 +63,18 @@ struct _glibtop_proc_segment
data_rss, /* data resident set size */
stack_rss, /* stack resident set size */
dirty_size, /* size of dirty pages */
- start_code,
- /* address of beginning of code segment */
+ start_code, /* address of beginning of code segment */
end_code, /* address of end of code segment */
- start_stack; /* address of the bottom of stack segment */
+ start_data, /* address of beginning of data segment */
+ end_data, /* address of end of data segment */
+ start_brk,
+ end_brk,
+ start_stack, /* address of the bottom of stack segment */
+ start_mmap,
+ arg_start,
+ arg_end,
+ env_start,
+ env_end;
};
#define glibtop_get_proc_segment(p1, p2) glibtop_get_proc_segment_l(glibtop_global_server, p1, p2)